@echo OFF
rem  * *******************************************************************
rem  *               SRIAOEW1.cmd - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2016 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  *
rem  * Text   - Sort ASCII-encoded file into an EBCDIC collating sequence
rem  * Author - SimoTime Technologies
rem  * Date   - January 01, 1989
rem  *
rem  * This example will sort an ASCII-encoded sequential file using
rem  * the ALTSEQ function of SORT to create an ASCII-encoded output
rem  * file that is arranged in an EBCDIC collating sequence.
rem  *
rem  * Note; Refer to SRTMKAJ8.jcl to create the data files to be used
rem  * as SORTIN.
rem  *
rem  * Step 1, DELSEQS1 will delete any previously created files.
rem  * Step 2, SRTSEQS3 will sort the file.
rem  *
rem  * CAUTION! Since the ALTSEQ is defined at the binary (or hexadecimal)
rem  *    level and step 3 will only work for ASCII-encoded files.
rem  *
rem  * This job uses sorting specifications (SYSIN) that are defined in
rem  * a Partitioned Data Set Member (PDSM).
rem  *
rem  * This set of programs will run on a mainframe under MVS or on a
rem  * Personal Computer with Windows and Micro Focus Mainframe Express.
rem  *
rem  * 1. Demonstrate how to use IEFBR14 with DD statements to delete
rem  *    files that have been created by a previous execution of this
rem  *    job.
rem  * 2. Demonstrate how to use the SORT program to sort a file based
rem  *    on the value in position five (5) of each record.
rem  *    This example uses a Partitioned Data Set Member (PDSM) to define
rem  *    the SORT specifications that include an ALTSEQ Table to sort
rem  *    an ASCII-encoded data file into an EBCDIC collating sequence.
rem  *
rem  * *******************************************************************
rem  * Step 1 of 2  Set the global environment variables...
rem  *              Delete any previously created file...
rem  * *******************************************************************
     set CmdName=SRIAOEW1
     call ..\Env1BASE %CmdName%
     if "%SYSLOG%" == "" set syslog=c:\SimoLIBR\LOGS\SimoTime.LOG
rem  *
     call SimoNOTE "*******************************************************%CmdName%"
     call SimoNOTE "Starting JobName %CmdName%, User is %USERNAME%"
     set DDSUASC1=%BaseLib1%\DATA\APPL\SIMOTIME.DATA.DDSUASC1.dat
     set DDSEASC1=%BaseLib1%\DATA\APPL\SIMOTIME.DATA.DDSEASC1.dat
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_SRIAOEW1.txt
     if exist %DDSEASC1% del %DDSEASC1%
rem  *
rem  * *******************************************************************
rem  * Step 2 of 2  Sort the file...
rem  *
     call SimoNOTE "Identify Sort the File"
     set SYSOUT=%BaseLib1%\LOGS\SYSOUT_SRIAOEW1_SORT.txt
     set SYSIN=%BaseLib1%\PARMLIB\SRTQIAOE.ctl
     set SORTIN=%DDSUASC1%
     set SORTOUT=%DDSEASC1%
     MFSORT take %SYSIN% use %SORTIN% RECORD F,80 ORG SQ GIVE %SORTOUT% RECORD F,80 ORG SQ
     if ERRORLEVEL = 1 set JobStatus=0020
     set SYSOUT=%SYSOUTSAVE%
     if not "%JobStatus%" == "0000" goto :EOJNOK
     if exist %DDSEASC1% goto :EOJAOK
        call SimoNOTE "ABENDING JobStep EOJNOK, Sort Failure..."
        goto :EOJNOK
rem  *
rem  * *******************************************************************
rem  *
:EOJNOK
     call SimoNOTE "ABENDING JobName %CmdName%, JobStatus %JobStatus%"
     call SimoNOTE "ABENDING Message JobStatus %JobStatus%"
     goto :EOJEND
:EOJAOK
     if exist %DDSEASC1% call SimoNOTE "Produced DataSet %DDSEASC1%"
     call SimoNOTE "Finished JobName %CmdName%"
:EOJEND
     call SimoNOTE "Conclude SysLog is %SYSLOG%"
     if not "%1" == "nopause" pause
